# Quple

A framework for quantum machine learning using the google cirq library

Documentation can be found [here](https://alkaidcheng.github.io/quple.github.io/docs/Quple_GSoC_report.pdf).

## Colab Notebook Tutorials

### Quantum Circuit / Parameterized Circuit
* [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/quple.github.io/blob/master/examples/Parameterized_Circuits_Walkthrough.ipynb)

### Interaction Graph
* [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/quple.github.io/blob/master/examples/Interaction_Graphs_Walkthrough.ipynb)

### Encoding Circuit
* [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/quple.github.io/blob/master/examples/Encoding_Circuit_Walkthrough.ipynb)

### Encoding Function
* [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/quple.github.io/blob/master/examples/Encoding_Function_Walkthrough.ipynb)

### Variational Circuit
* [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/quple.github.io/blob/master/examples/Variational_Circuits_Walkthrough.ipynb)

### Variational Quantum Classifier
* [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/quple.github.io/blob/master/examples/Variational_Quantum_Classifier_Walkthrough.ipynb)

### Circuit Descriptors
* [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/quple.github.io/blob/master/examples/Circuit_Descriptors_Walkthrough.ipynb)

### Extra Features
* [![Open In Colab](https://colab.research.google.com/assets/colab-badge.svg)](https://colab.research.google.com/github/AlkaidCheng/quple.github.io/blob/master/examples/Feature_Updates_Jul_7.ipynb)
